pub struct Chat {
pub id: ChatId,
pub chat_type: ChatType,
pub messages: Vec<ChatMessage>,
pub last_read_message_id: Option<ChatMessageId>,
}Fields
id: ChatIdchat_type: ChatTypemessages: Vec<ChatMessage>last_read_message_id: Option<ChatMessageId>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Chat
impl<'de> Deserialize<'de> for Chat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for Chatwhere
Self: DeserializeOwned,
impl FromWasmAbi for Chatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for Chat
impl IntoWasmAbi for Chat
Sourceimpl JsonSchema for Chat
impl JsonSchema for Chat
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for Chatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for Chatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for Chat
impl OptionIntoWasmAbi for Chat
Sourceimpl RefFromWasmAbi for Chatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for Chatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for Chat
impl Tsify for Chat
const DECL: &'static str = "export interface Chat {\n id: ChatId;\n chat_type: ChatType;\n messages: ChatMessage[];\n last_read_message_id: ChatMessageId | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for Chatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for Chatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for Chat
impl VectorIntoWasmAbi for Chat
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi