pub struct ChatMessage {
pub id: Option<ChatMessageId>,
pub sender_character_id: Uuid,
pub recipient_character_id: Option<Uuid>,
pub chat_id: Option<ChatId>,
pub chat_type: ChatType,
pub text: String,
pub created_at: DateTime<Utc>,
}Fields
id: Option<ChatMessageId>sender_character_id: Uuidrecipient_character_id: Option<Uuid>chat_id: Option<ChatId>chat_type: ChatTypetext: Stringcreated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ChatMessage
impl Clone for ChatMessage
Sourcefn clone(&self) -> ChatMessage
fn clone(&self) -> ChatMessage
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatMessage
impl Debug for ChatMessage
Sourceimpl<'de> Deserialize<'de> for ChatMessage
impl<'de> Deserialize<'de> for ChatMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatMessage> for JsValuewhere
ChatMessage: Serialize,
impl From<ChatMessage> for JsValuewhere
ChatMessage: Serialize,
Sourcefn from(value: ChatMessage) -> Self
fn from(value: ChatMessage) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
impl FromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ChatMessagewhere
ChatMessage: Serialize,
impl IntoWasmAbi for ChatMessagewhere
ChatMessage: Serialize,
Sourceimpl JsonSchema for ChatMessage
impl JsonSchema for ChatMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ChatMessagewhere
ChatMessage: Serialize,
impl OptionIntoWasmAbi for ChatMessagewhere
ChatMessage: Serialize,
Sourceimpl PartialEq for ChatMessage
impl PartialEq for ChatMessage
Sourceimpl RefFromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ChatMessage>
type Anchor = SelfOwner<ChatMessage>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ChatMessage
impl Serialize for ChatMessage
Sourceimpl Tsify for ChatMessage
impl Tsify for ChatMessage
const DECL: &'static str = "export interface ChatMessage {\n id: ChatMessageId | null;\n sender_character_id: Uuid;\n recipient_character_id: Uuid | null;\n chat_id: ChatId | null;\n chat_type: ChatType;\n text: string;\n created_at: DateTime<Utc>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ChatMessagewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ChatMessagewhere
ChatMessage: Serialize,
impl VectorIntoWasmAbi for ChatMessagewhere
ChatMessage: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ChatMessage
impl WasmDescribeVector for ChatMessage
impl Eq for ChatMessage
impl StructuralPartialEq for ChatMessage