pub struct ChatSettings {
pub chat_type: ChatType,
pub user_allowed_to_write: bool,
pub get_notification_on_messages: bool,
}Fields
chat_type: ChatTypeuser_allowed_to_write: boolget_notification_on_messages: boolTrait Implementations
Sourceimpl Clone for ChatSettings
impl Clone for ChatSettings
Sourcefn clone(&self) -> ChatSettings
fn clone(&self) -> ChatSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatSettings
impl Debug for ChatSettings
Sourceimpl<'de> Deserialize<'de> for ChatSettings
impl<'de> Deserialize<'de> for ChatSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChatSettings> for JsValuewhere
ChatSettings: Serialize,
impl From<ChatSettings> for JsValuewhere
ChatSettings: Serialize,
Sourcefn from(value: ChatSettings) -> Self
fn from(value: ChatSettings) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
impl FromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ChatSettingswhere
ChatSettings: Serialize,
impl IntoWasmAbi for ChatSettingswhere
ChatSettings: Serialize,
Sourceimpl JsonSchema for ChatSettings
impl JsonSchema for ChatSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ChatSettingswhere
ChatSettings: Serialize,
impl OptionIntoWasmAbi for ChatSettingswhere
ChatSettings: Serialize,
Sourceimpl RefFromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ChatSettings>
type Anchor = SelfOwner<ChatSettings>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ChatSettings
impl Serialize for ChatSettings
Sourceimpl Tsify for ChatSettings
impl Tsify for ChatSettings
const DECL: &'static str = "export interface ChatSettings {\n chat_type: ChatType;\n user_allowed_to_write: boolean;\n get_notification_on_messages: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ChatSettingswhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ChatSettingswhere
ChatSettings: Serialize,
impl VectorIntoWasmAbi for ChatSettingswhere
ChatSettings: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ChatSettings
impl WasmDescribeVector for ChatSettings