pub struct ReadMessage {
pub chat_id: ChatId,
pub message_id: ChatMessageId,
}Fields
chat_id: ChatIdmessage_id: ChatMessageIdTrait Implementations
Sourceimpl Clone for ReadMessage
impl Clone for ReadMessage
Sourcefn clone(&self) -> ReadMessage
fn clone(&self) -> ReadMessage
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadMessage
impl Debug for ReadMessage
Sourceimpl<'de> Deserialize<'de> for ReadMessage
impl<'de> Deserialize<'de> for ReadMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ReadMessage> for JsValuewhere
ReadMessage: Serialize,
impl From<ReadMessage> for JsValuewhere
ReadMessage: Serialize,
Sourcefn from(value: ReadMessage) -> Self
fn from(value: ReadMessage) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
impl FromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ReadMessagewhere
ReadMessage: Serialize,
impl IntoWasmAbi for ReadMessagewhere
ReadMessage: Serialize,
Sourceimpl JsonSchema for ReadMessage
impl JsonSchema for ReadMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ReadMessagewhere
ReadMessage: Serialize,
impl OptionIntoWasmAbi for ReadMessagewhere
ReadMessage: Serialize,
Sourceimpl RefFromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ReadMessage>
type Anchor = SelfOwner<ReadMessage>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ReadMessage
impl Serialize for ReadMessage
Sourceimpl Tsify for ReadMessage
impl Tsify for ReadMessage
const DECL: &'static str = "export interface ReadMessage {\n chat_id: ChatId;\n message_id: ChatMessageId;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ReadMessagewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ReadMessagewhere
ReadMessage: Serialize,
impl VectorIntoWasmAbi for ReadMessagewhere
ReadMessage: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ReadMessage
impl WasmDescribeVector for ReadMessage