pub struct ReportChatMessage {
pub message_id: ChatMessageId,
}Fields
message_id: ChatMessageIdTrait Implementations
Sourceimpl Clone for ReportChatMessage
impl Clone for ReportChatMessage
Sourcefn clone(&self) -> ReportChatMessage
fn clone(&self) -> ReportChatMessage
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReportChatMessage
impl Debug for ReportChatMessage
Sourceimpl<'de> Deserialize<'de> for ReportChatMessage
impl<'de> Deserialize<'de> for ReportChatMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ReportChatMessage> for JsValuewhere
ReportChatMessage: Serialize,
impl From<ReportChatMessage> for JsValuewhere
ReportChatMessage: Serialize,
Sourcefn from(value: ReportChatMessage) -> Self
fn from(value: ReportChatMessage) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
impl FromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ReportChatMessagewhere
ReportChatMessage: Serialize,
impl IntoWasmAbi for ReportChatMessagewhere
ReportChatMessage: Serialize,
Sourceimpl JsonSchema for ReportChatMessage
impl JsonSchema for ReportChatMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ReportChatMessagewhere
ReportChatMessage: Serialize,
impl OptionIntoWasmAbi for ReportChatMessagewhere
ReportChatMessage: Serialize,
Sourceimpl RefFromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ReportChatMessage>
type Anchor = SelfOwner<ReportChatMessage>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ReportChatMessage
impl Serialize for ReportChatMessage
Sourceimpl Tsify for ReportChatMessage
impl Tsify for ReportChatMessage
const DECL: &'static str = "export interface ReportChatMessage {\n message_id: ChatMessageId;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ReportChatMessagewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ReportChatMessagewhere
ReportChatMessage: Serialize,
impl VectorIntoWasmAbi for ReportChatMessagewhere
ReportChatMessage: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ReportChatMessage
impl WasmDescribeVector for ReportChatMessage